library(shiny)
ui <-
  navbarPage(
    strong("Flow through vessels (The Hagen-Poiseuille Law)"),
    
    tabPanel(
      strong("Experiment 1"),
      titlePanel(
        h4(
          "Flow depending on the pressure difference and resistance calculation"
        )
      ),
      
      tabsetPanel(
        tabPanel("Experimental setup",
                 mainPanel((
                   img(
                     src = "VersuchAufbau1.png",
                     height = 674,
                     width = 1013
                   )
                 ))),
        
        
        tabPanel(
          "Task",
          br(),
          sidebarPanel(
            "",
            sliderInput(
              inputId = "slider",
              label = "The length between the standpipe and the outflow is 46 cm and the pipe diameter is 4.5 mm. Choose 5 of these 10 heights:",
              min = 1,
              max = 10,
              value = 1,
              step = 1
            )
          ),
          
          mainPanel(conditionalPanel("input.slider=='1'",
                                     
                                     ((
                                       img(
                                         src = "H1.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='2'",
                                     
                                     ((
                                       img(
                                         src = "H2.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='3'",
                                     
                                     ((
                                       img(
                                         src = "H3.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='4'",
                                     
                                     ((
                                       img(
                                         src = "H4.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='5'",
                                     
                                     ((
                                       img(
                                         src = "H5.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='6'",
                                     
                                     ((
                                       img(
                                         src = "H6.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='7'",
                                     
                                     ((
                                       img(
                                         src = "H7.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='8'",
                                     
                                     ((
                                       img(
                                         src = "H8.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='9'",
                                     
                                     ((
                                       img(
                                         src = "H9.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.slider=='10'",
                                     
                                     ((
                                       img(
                                         src = "H10.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     ))))
        )
      ),
      
      list(tags$head(
        tags$style("body {background-color: #BEBEBE; }")
      ))
    ),
    
    
    
    tabPanel(
      strong("Experiment 2"),
      titlePanel(h4("Flow as a function of the pipe radius")),
      
      tabsetPanel(
        tabPanel("Pipe diameter",
                 br(),
                 mainPanel((
                   img(
                     src = "SdRRohre2.png",
                     height = 674,
                     width = 1013
                   )
                 ))),
        
        
        tabPanel(
          "Task",
          br(),
          sidebarPanel(
            "",
            radioButtons(
              "typeInput",
              "The length between the standpipe and the outflow is 46 cm each. (Repeat measurements are not required here!)",
              choices = c("Thick pipe", "Thin pipe"),
              selected = "Thick pipe"
            )
          ),
          
          
          mainPanel(conditionalPanel("input.typeInput=='Thick pipe'",
                                     
                                     ((
                                       img(
                                         src = "GrossesRohr2.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.typeInput=='Thin pipe'",
                                     
                                     ((
                                       img(
                                         src = "KleinesRohr2.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     ))))
        )
      )
    ),
    
    
    
    
    tabPanel(
      strong("Experiment 3"),
      titlePanel(
        h4(
          "Pressure along a flow pipe with a constant inner diameter."
        )
      ),
      
      tabsetPanel(
        tabPanel("Experimental setup",
                 br(),
                 mainPanel((
                   img(
                     src = "VersuchAufbau3.jpg",
                     height = 674,
                     width = 1013
                   )
                 ))),
        
        tabPanel("Dimension of the pipes",
                 br(),
                 mainPanel((
                   img(
                     src = "Versuch3Rohr.jpg",
                     height = 674,
                     width = 1013
                   )
                 ))),
        
        
        tabPanel(
          "Task",
          br(),
          sidebarPanel(
            "",
            radioButtons(
              "type",
              "Note that the direction of flow is from RIGHT to LEFT! Choose different heights:",
              choices = c("Heights 1", "Heights 2", "Heights 3"),
              selected = "Heights 1"
            )
          ),
          
          
          mainPanel(conditionalPanel("input.type=='Heights 1'",
                                     
                                     ((
                                       img(
                                         src = "V3H1.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.type=='Heights 2'",
                                     
                                     ((
                                       img(
                                         src = "V3H2.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.type=='Heights 3'",
                                     
                                     ((
                                       img(
                                         src = "V3H3.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     ))))
        )
      )
    ),
    
    
    
    tabPanel(
      strong("Experiment 4"),
      titlePanel(
        h4(
          "Pressure along a flow pipe with different inner diameters."
        )
      ),
      
      tabsetPanel(
        tabPanel("Experimental setup",
                 br(),
                 mainPanel((
                   img(
                     src = "VersuchAufbau4.jpg",
                     height = 674,
                     width = 1013
                   )
                 ))),
        
        tabPanel("Dimension of the pipes",
                 br(),
                 mainPanel((
                   img(
                     src = "Versuch4Rohr.jpg",
                     height = 674,
                     width = 1013
                   )
                 ))),
        
        
        tabPanel(
          "Task",
          br(),
          sidebarPanel(
            "",
            radioButtons(
              "radio",
              "Note that the direction of flow is from RIGHT to LEFT! Choose different heights:",
              choices = c("Heights 1", "Heights 2", "Heights 3"),
              selected = "Heights 1"
            )
          ),
          
          
          mainPanel(conditionalPanel("input.radio=='Heights 1'",
                                     
                                     ((
                                       img(
                                         src = "V4H1.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.radio=='Heights 2'",
                                     
                                     ((
                                       img(
                                         src = "V4H2.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     )))),
          
          mainPanel(conditionalPanel("input.radio=='Heights 3'",
                                     
                                     ((
                                       img(
                                         src = "V4H3.png",
                                         height = 674,
                                         width = 1013
                                       )
                                     ))))
        )
      )
    )
  )



server <- function(input, output) {
}

shinyApp(ui = ui, server = server)